.. _tutorials:

#########
Tutorials
#########

The tutorials featured here illustrate actual cases of ``alchemiscale`` use alongside other tools.
These are meant to supplement the :ref:`user-guide`, which focuses on the general pattern of ``alchemiscale`` usage outside of any particular use case.


.. toctree::
   :maxdepth: 1

   ./demo/Alchemiscale Demo.ipynb
